1.0.0 API documentation: matrix_access.hpp Source File

| 1.0.0 API documentation

matrix_access.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependency:
16 #include "../detail/setup.hpp"
17
18 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
19 # pragma message("GLM: GLM_GTC_matrix_access extension included")
20 #endif
21
22 namespace glm
23 {
26
29 template<typename genType>
30 GLM_FUNC_DECL typename genType::row_type row(
31 genType const& m,
32 length_t index);
33
36 template<typename genType>
37 GLM_FUNC_DECL genType row(
38 genType const& m,
39 length_t index,
40 typename genType::row_type const& x);
41
44 template<typename genType>
45 GLM_FUNC_DECL typename genType::col_type column(
46 genType const& m,
47 length_t index);
48
51 template<typename genType>
52 GLM_FUNC_DECL genType column(
53 genType const& m,
54 length_t index,
55 typename genType::col_type const& x);
56
58 }//namespace glm
59
60 #include "matrix_access.inl"
glm::row
GLM_FUNC_DECL genType row(genType const &m, length_t index, typename genType::row_type const &x)
Set a specific row to a matrix.
glm::column
GLM_FUNC_DECL genType column(genType const &m, length_t index, typename genType::col_type const &x)
Set a specific column to a matrix.